Accepts the three shapes combinations arrive in: a character vector of
combination ids, a list of integer vectors, or a ptsdiag_spec from
read_combinations.
Value
A list with mat, an integer matrix of one row per combination, and
ids, the corresponding combination ids.
Examples
as_set_matrix(c("1_2_3_4_5_6", "2_3_6_7_17_18"))
#> $mat
#> [,1] [,2] [,3] [,4] [,5] [,6]
#> [1,] 1 2 3 4 5 6
#> [2,] 2 3 6 7 17 18
#>
#> $ids
#> [1] "1_2_3_4_5_6" "2_3_6_7_17_18"
#>